#
# spec file for package vmaf
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum  1
%define lname   libvmaf%sonum

# undefined reference to `vmaf_cpu_cpuid'
%define _lto_cflags %{nil}
Name:           vmaf
Version:        2.1.1
Release:        bp153.1.1
Summary:        Perceptual video quality assessment algorithm
License:        BSD-2-Clause-Patent AND BSD-3-Clause
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://github.com/Netflix/vmaf
Source:         https://github.com/Netflix/vmaf/archive/v%version.tar.gz
Source9:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  meson >= 0.47
BuildRequires:  nasm
BuildRequires:  pkg-config
Provides:       bundled(libsvm) = 3.18

%description
VMAF is a perceptual video quality assessment algorithm.

%package -n %lname
Summary:        Perceptual video quality assessment algorithm
Group:          System/Libraries
Recommends:     %name-data

%description -n %lname
VMAF is a perceptual video quality assessment algorithm.

%package devel
Summary:        Development tools for Video Multi-Method Assessment Fusion
Group:          Development/Libraries/C and C++
Requires:       %lname = %version-%release

%description devel
VMAF is a perceptual video quality assessment algorithm developed by
Netflix.
This package contains the library API definitions.

%prep
%autosetup

%build
rm -rf third_party
pushd libvmaf/
%meson
%meson_build
popd

%install
pushd libvmaf/
%meson_install
popd
rm -f "%buildroot/%_libdir"/*.a
%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libvmaf.so.%{sonum}*

%files devel
%_bindir/vmaf*
%_includedir/libvmaf/
%_libdir/libvmaf.so
%_libdir/pkgconfig/*.pc
%license LICENSE
%doc FAQ.md README.md

%changelog
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 2.1.1:
  * Fixes a SSIM/MS-SSIM precision bug where a lossless comparison did not
    always result in a perfect 1.0 score. (#796).
  * Adds feature extractor options to clip the dB scores for both PSNR/SSIM.
  - -aom_ctc v1.0 has been updated to use these clipping options according to
    the AOM CTC. (#802).
- disable LTO build (fails at least since 2.1.0)
* Thu Jan  7 2021 ecsos <ecsos@opensuse.org>
- Update to 2.1.0
  * New features:
  - Per-model feature overloading via new API
    vmaf_model_feature_overload().
  - Multiple unique configurations of the same feature extractor
    may be registered run at the same time.
  - --aom_ctc v1.0 preset, encompassing all metrics specified by
    the AOM CTC.
- Changes from 2.0.0
  * New features:
  - Add PSNR-HVS and CIEDE2000 metrics.
  - ci/actions: upload linux/macos artifacts (#738)
  - libvmaf/feature: deprecate daala_ssim (#735)
  - libvmaf: remove support for pkl models
  - libvmaf/psnr: rewrite using integer types, 2x speedup
  - vmaf: if no model is specified, enable v0.6.1 by default (#730)
  - libvmaf/x86: add AVX2/AVX-512 optimizations for adm, vif and
    motion
  - ci/actions: add xxd to build dependencies for Windows
  - libvmaf: add support for built-in models
  - libvmaf/integer_vif: use symmetrical mirroring on edges
  - Fix log2 by replacing log2f_approx with log2f
  - libvmaf_rc: provide a backwards compatible compute_vmaf(),
    link vmafossexec with libvmaf
  - libvmaf: add framework support for json models
  - libvmaf/libsvm: update libsvm to version 324
  - libvmaf/motion: add motion_force_zero to motion fex
  - return sha1 if Asset string is longer than 255
  - Add CID/iCID Matlab source code
  - build: unbreak x86 builds (Fixes: #374)
  - Add 12bit and 16bit support for python YUV reader; add tests.
  - Add PypsnrFeatureExtractor
  - Add processes to FeatureAssembler. (#662)
  * Fixed bugs:
  - fix motion flush for single frame input
  - Fixing the perf_metric for a single entry list input
- Drop 0001-build-unbreak-x86-builds.patch, because now in upstream.
- Remove data subpackage because models now build in.
* Mon Oct 19 2020 Jan Engelhardt <jengelh@inai.de>
- Add missing BuildRequires: pkg-config. This is still needed
  for rpm to pick up .pc and generate pkgconfig() symbols.
* Sat Oct 17 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 1.5.3) for build.opensuse.org
- Add 0001-build-unbreak-x86-builds.patch
